@@ -52,7 +52,7 @@ class DMD:
 
 class TVERA:
     def __init__(self, free_decay_experiments, hki, D, state_dimension, p, q, **kwargs):
-        self.A, self.B, self.C, self.D, self.Ok, self.Ok1, self.sigma, self.A_id, self.B_id, self.C_id, self.D_id = timeVaryingEigenSystemRealizationAlgorithm(free_decay_experiments, hki, D, state_dimension, p, q, **kwargs)
+        self.A, self.B, self.C, self.D, self.Ok, self.Ok1, self.sigma, self.A_id, self.B_id, self.C_id, self.D_id, self.Y = timeVaryingEigenSystemRealizationAlgorithm(free_decay_experiments, hki, D, state_dimension, p, q, **kwargs)
 
 
 
