@@ -62,7 +62,7 @@ def time_varying_eigensystem_realization_algorithm(hki, D, frequency, state_dime
     free_response_signals = kwargs.get('free_response_signals', [])
     number_experiments = len(free_response_signals)
     if number_experiments > 0:
-        _, _, Ok_tvera_ic, Ok1_tvera_ic, Sigma_tvera_ic, X0_tvera_ic, A_id_tvera_ic, C_id_tvera_ic, MAC_tvera_ic, MSV_tvera_ic, _ = time_varying_eigensystem_realization_algorithm_from_initial_condition_response(free_response_signals, state_dimension, p, show_progress=show_progress, mac_msv=mac_msv, max_time_step=q)
+        _, _, Ok_tvera_ic, Ok1_tvera_ic, Sigma_tvera_ic, X0_tvera_ic, A_id_tvera_ic, C_id_tvera_ic, MAC_tvera_ic, MSV_tvera_ic, Y = time_varying_eigensystem_realization_algorithm_from_initial_condition_response(free_response_signals, state_dimension, p, show_progress=show_progress, mac_msv=mac_msv, max_time_step=q)
 
     A_id[:, :, 0:q] = A_id_tvera_ic[:, :, 0:q]
     C_id[:, :, 0:q] = C_id_tvera_ic[:, :, 0:q]
@@ -85,7 +85,7 @@ def time_varying_eigensystem_realization_algorithm(hki, D, frequency, state_dime
     for k in range(q, number_steps - p - 1):
 
         if show_progress:
-            print('Step', k + 1, 'out of', number_steps - p)
+            print('Step', k + 1, 'out of', number_steps - p - 1)
 
 
         Hpq2 = np.zeros([(p + 1) * output_dimension, q * input_dimension])
@@ -141,11 +141,13 @@ def time_varying_eigensystem_realization_algorithm(hki, D, frequency, state_dime
         if apply_transformation:
             Tkp1 = np.matmul(LA.pinv(Ok[:, :, q]), Ok1[:, :, k])
             Tk = np.matmul(LA.pinv(Ok[:, :, q]), Ok[:, :, k])
-            A_id[:, :, k] = np.matmul(Tkp1, A_id[:, :, k], LA.pinv(Tk))
-            B_id[:, :, k] = np.matmul(Tkp1, np.matmul(LA.pinv(O2), Hp1))
+
+            A_id[:, :, k] = np.matmul(Tkp1, np.matmul(A_id[:, :, k], LA.pinv(Tk)))
+            B_id[:, :, k] = np.matmul(Tkp1, np.matmul(LA.pinv(Ok1[:, :, k]), Hp1))
             C_id[:, :, k] = np.matmul(C_id[:, :, k], LA.pinv(Tk))
+
         else:
-            B_id[:, :, k] = np.matmul(LA.pinv(O2), Hp1)
+            B_id[:, :, k] = np.matmul(LA.pinv(Ok1[:, :, k]), Hp1)
 
 
     # Create corresponding functions
